From: Karol Kozimor <sziwan@hell.org.pl>
To: "Brown, Len" <len.brown@intel.com>
Cc: linux-acpi@vger.kernel.org
Subject: [PATCH 4/10] support W3400N
Date: Sat, 1 Jul 2006 01:05:09 +0200 [thread overview]
Message-ID: <20060630230509.GF31642@hell.org.pl> (raw)
In-Reply-To: <20060630225905.GB31642@hell.org.pl>
This patch adds support for Asus W3400N.
Signed-off-by: Karol Kozimor <sziwan@hell.org.pl>
--- a/drivers/acpi/asus_acpi.c 2006-01-18 17:32:25.000000000 +0100
+++ b/drivers/acpi/asus_acpi.c 2006-01-18 17:36:00.000000000 +0100
@@ -130,7 +130,7 @@ struct asus_hotk {
L8L, //L8400L
M1A, //M1300A
M2E, //M2400E, L4400L
- M6N, //M6800N
+ M6N, //M6800N, W3400N
M6R, //M6700R, A3000G
P30, //Samsung P30
S1x, //S1300A, but also L1400B and M2400A (L84F)
@@ -1090,7 +1090,8 @@ static int __init asus_hotk_get_info(voi
hotk->model = L8L;
else if (strncmp(model->string.pointer, "L4R", 3) == 0)
hotk->model = L4R;
- else if (strncmp(model->string.pointer, "M6N", 3) == 0)
+ else if (strncmp(model->string.pointer, "M6N", 3) == 0 ||
+ strncmp(model->string.pointer, "W3N", 3) == 0)
hotk->model = M6N;
else if (strncmp(model->string.pointer, "M6R", 3) == 0 ||
strncmp(model->string.pointer, "A3G", 3) == 0)
@@ -1143,9 +1144,10 @@ static int __init asus_hotk_get_info(voi
hotk->methods->lcd_status = "\\BLFG";
/* A3G is like M6R */
else if (strncmp(model->string.pointer, "S5N", 3) == 0 ||
- strncmp(model->string.pointer, "M5N", 3) == 0)
+ strncmp(model->string.pointer, "M5N", 3) == 0 ||
+ strncmp(model->string.pointer, "W3N", 3) == 0)
hotk->methods->mt_mled = NULL;
/* S5N and M5N have no MLED */
else if (strncmp(model->string.pointer, "M2N", 3) == 0)
hotk->methods->mt_wled = "WLED";
/* M2N has a usable WLED */
next prev parent reply other threads:[~2006-06-30 23:05 UTC|newest]
Thread overview: 21+ messages / expand[flat|nested] mbox.gz Atom feed top
2006-01-18 21:21 [PATCH 0/9] drivers/acpi/asus_acpi.c updates Karol Kozimor
2006-01-18 21:26 ` [PATCH 1/9] misc cleanups Karol Kozimor
2006-01-18 21:28 ` [PATCH 2/9] support A3G Karol Kozimor
2006-01-18 21:36 ` [PATCH 3/9] LED display support Karol Kozimor
2006-01-18 21:38 ` [PATCH 4/9] support W3400N Karol Kozimor
2006-01-18 21:41 ` [PATCH 5/9] support A4G Karol Kozimor
2006-01-18 21:48 ` [PATCH 6/9] handle internal Bluetooth / support W5A Karol Kozimor
2006-01-18 21:52 ` [PATCH 7/9] support L5D Karol Kozimor
2006-01-18 22:02 ` [PATCH 8/9] rework model detection Karol Kozimor
2006-01-18 22:04 ` [PATCH 9/9] add S1N WLED control Karol Kozimor
2006-06-30 22:59 ` [PATCH 0/10] drivers/acpi/asus_acpi.c updates [RESEND] Karol Kozimor
2006-06-30 23:02 ` [PATCH 1/10] misc cleanups Karol Kozimor
2006-06-30 23:03 ` [PATCH 2/10] support A3G Karol Kozimor
2006-06-30 23:04 ` [PATCH 3/10] LED display support Karol Kozimor
2006-06-30 23:05 ` Karol Kozimor [this message]
2006-06-30 23:05 ` [PATCH 5/10] support A4G Karol Kozimor
2006-06-30 23:07 ` [PATCH 6/10] handle internal Bluetooth / support W5A Karol Kozimor
2006-06-30 23:08 ` [PATCH 7/10] support L5D Karol Kozimor
2006-06-30 23:11 ` [PATCH 8/10] rework model detection Karol Kozimor
2006-06-30 23:12 ` [PATCH 9/10] add S1N WLED control Karol Kozimor
2006-06-30 23:14 ` [PATCH 10/10] " Karol Kozimor
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20060630230509.GF31642@hell.org.pl \
--to=sziwan@hell.org.pl \
--cc=len.brown@intel.com \
--cc=linux-acpi@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1143,9 +1144,10 @@ static int __init asus_hotk_get_info(voi
hotk->methods->mt_mled = NULL;
- /* S5N and M5N have no MLED */
+ /* S5N, M5N and W3N have no MLED */
else if (strncmp(model->string.pointer, "M2N", 3) == 0)
hotk->methods->mt_wled = "WLED";
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.